package com.amms.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.amms.domain.Tourist;

/**
 * 普通用户子Mapper接口
 */
@Mapper
public interface TouristMapper {
    /**
     * 查询普通用户子
     *
     * @param id 普通用户子主键
     * @return 普通用户子
     */
    public Tourist selectTouristById(Long id);

    /**
     * 查询普通用户子列表
     *
     * @param tourist 普通用户子
     * @return 普通用户子集合
     */
    public List<Tourist> selectTouristList(Tourist tourist);

    /**
     * 新增普通用户子
     *
     * @param tourist 普通用户子
     * @return 结果
     */
    public int insertTourist(Tourist tourist);

    /**
     * 修改普通用户子
     *
     * @param tourist 普通用户子
     * @return 结果
     */
    public int updateTourist(Tourist tourist);

    /**
     * 删除普通用户子
     *
     * @param id 普通用户子主键
     * @return 结果
     */
    public int deleteTouristById(Long id);

}
